'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('./extends-338edd51.js');
var _styled = require('styled-components');
var React = require('react');
var web = require('./web-73b24345.js');
var propTypes = require('./prop-types-de58d4ad.js');
var css = require('./css.js');
var constants = require('./constants.js');
var springs = require('./springs.js');
require('./index-00b34fc0.js');
require('react-dom');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const LABELS_HEIGHT = 30;
const WIDTH_DEFAULT = 300;

function useMeasuredWidth() {
  const ref = React.useRef();
  const [measuredWidth, setMeasuredWidth] = React.useState(WIDTH_DEFAULT);
  const onResize = React.useCallback(() => {
    if (ref.current) {
      setMeasuredWidth(ref.current.clientWidth);
    }
  }, []);
  const onRef = React.useCallback(element => {
    ref.current = element;
    onResize();
  }, [onResize]);
  React.useEffect(() => {
    window.addEventListener('resize', onResize);
    return () => window.removeEventListener('resize', onResize);
  }, [onResize]);
  return [measuredWidth, onRef];
}

const OFFSET = 50;

function LineChart(_ref) {
  let {
    animDelay,
    borderColor,
    color,
    dotRadius,
    height,
    label,
    labelColor,
    lines: linesProps,
    renderCheckpoints,
    reset,
    scales,
    springConfig,
    threshold,
    total,
    width: widthProps,
    ...props
  } = _ref;
  const [width, onSvgRef] = useMeasuredWidth();
  const lines = React.useMemo(() => {
    return linesProps.map(lineOrValues => Array.isArray(lineOrValues) ? {
      values: lineOrValues
    } : lineOrValues);
  }, [linesProps]); // the count of provided values

  const valuesCount = React.useMemo(() => {
    // All the values have the same length, so we can use the first one.
    return lines[0] ? lines[0].values.length : 0;
  }, [lines]); // the total amount of values

  const totalCount = React.useMemo(() => {
    // If no total is provided, the total is the number of provided values.
    return total > 0 && total > valuesCount ? total : valuesCount;
  }, [valuesCount, total]);
  const getX = React.useCallback(index => {
    return width / Math.max(1, totalCount - 1) * index;
  }, [width, totalCount]);
  const getY = React.useCallback((percentage, progress, height) => {
    const padding = dotRadius + 2;
    return height - padding - (height - padding * 2) * percentage * progress;
  }, [dotRadius]);
  const getLabelPosition = React.useCallback((index, length) => {
    if (index === 0) {
      return 'start';
    }

    if (index === length - 1) {
      return 'end';
    }

    return 'middle';
  }, []);
  const labels = label && totalCount > 0 ? [...Array(totalCount).keys()].map(label) : null;
  const chartHeight = height - (labels ? LABELS_HEIGHT : 0);
  return /*#__PURE__*/React__default["default"].createElement(web.Spring, {
    from: {
      progress: 0
    },
    to: {
      progress: 1
    },
    config: springConfig,
    delay: animDelay,
    reset: reset
  }, _ref2 => {
    let {
      progress
    } = _ref2;
    return /*#__PURE__*/React__default["default"].createElement(_StyledSvg, _extends._extends({
      ref: onSvgRef,
      viewBox: `0 0 ${width + OFFSET} ${height + constants.GU}`,
      width: widthProps || 'auto',
      height: "auto"
    }, props), /*#__PURE__*/React__default["default"].createElement("g", {
      mask: "url(#chart-mask)",
      transform: `translate(0,${constants.GU})`
    }, totalCount > 0 && /*#__PURE__*/React__default["default"].createElement("path", {
      d: `
                  ${[...new Array(totalCount - 1)].reduce((path, _, index) => `${path} M ${getX(index)},${!index ? 0 : chartHeight} l 0,-8`, '')}
                `,
      stroke: borderColor,
      strokeWidth: "1"
    }), lines.map((line, lineIndex) => {
      return /*#__PURE__*/React__default["default"].createElement("g", {
        key: `line-plot-${line.id || lineIndex}`
      }, /*#__PURE__*/React__default["default"].createElement("path", {
        d: `
                    M
                    ${getX(0)},
                    ${getY(line.values[0], progress, chartHeight)}

                    ${line.values.slice(1).map((val, index) => {
          return `L
                           ${getX((index + 1) * progress)},
                           ${getY(val, progress, chartHeight, index)}
                          `;
        }).join('')}
                  `,
        fill: "transparent",
        stroke: line.color || color(lineIndex, {
          lines
        }),
        strokeWidth: "2"
      }), renderCheckpoints && line.values.slice(1, -1).map((val, index) => {
        return /*#__PURE__*/React__default["default"].createElement("circle", {
          key: index,
          cx: getX(index + 1) * progress,
          cy: getY(val, progress, chartHeight),
          r: dotRadius,
          fill: color() || 'white',
          stroke: line.color || color(lineIndex, {
            lines
          }),
          strokeWidth: "1"
        });
      }));
    })), labels && /*#__PURE__*/React__default["default"].createElement("g", {
      transform: `translate(0,${chartHeight})`
    }, labels.map((label, index) => /*#__PURE__*/React__default["default"].createElement(_StyledText, {
      key: index,
      x: getX(index),
      y: LABELS_HEIGHT,
      textAnchor: getLabelPosition(index, labels.length),
      fill: labelColor
    }, label))), /*#__PURE__*/React__default["default"].createElement("g", {
      transform: `translate(0,${constants.GU})`
    }, scales && scales.map((_ref3, index) => {
      let {
        label,
        highlightColor
      } = _ref3;
      const scaleLength = scales.length - 1;
      return /*#__PURE__*/React__default["default"].createElement(_StyledText2, {
        key: index,
        x: width + OFFSET / 8,
        y: chartHeight - chartHeight / scaleLength * index + constants.GU / 2,
        textAnchor: getLabelPosition(0, labels.length),
        fill: highlightColor || labelColor,
        $_css: highlightColor && `
                        font-weight: 800;
                        font-size
                      `
      }, label);
    })), threshold && /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("line", {
      x1: 0,
      y1: chartHeight / (scales.length - 1) + constants.GU,
      x2: width,
      y2: chartHeight / (scales.length - 1) + constants.GU,
      style: {
        stroke: '#952828',
        strokeWidth: 2
      }
    }), ' ', /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("linearGradient", {
      id: "thresholdFill",
      x1: "0",
      x2: "0",
      y1: "0",
      y2: "1"
    }, /*#__PURE__*/React__default["default"].createElement("stop", {
      offset: "0%",
      stopColor: "red",
      stopOpacity: "0"
    }), /*#__PURE__*/React__default["default"].createElement("stop", {
      offset: "100%",
      stopColor: "#952828",
      stopOpacity: "30%"
    }))), /*#__PURE__*/React__default["default"].createElement("rect", {
      x: 0,
      y: 0,
      width: width,
      height: chartHeight / (scales.length - 1) + constants.GU,
      fill: "url(#thresholdFill)"
    })));
  });
}

LineChart.propTypes = {
  springConfig: propTypes.PropTypes._spring,
  total: propTypes.PropTypes.number,
  width: propTypes.PropTypes.number,
  height: propTypes.PropTypes.number,
  dotRadius: propTypes.PropTypes.number,
  animDelay: propTypes.PropTypes.number,
  borderColor: propTypes.PropTypes.string,
  labelColor: propTypes.PropTypes.string,
  lines: propTypes.PropTypes.arrayOf(propTypes.PropTypes.oneOfType([propTypes.PropTypes.shape({
    id: propTypes.PropTypes.number,
    values: propTypes.PropTypes.arrayOf(propTypes.PropTypes.number).isRequired,
    // numbers between 0 and 1
    color: propTypes.PropTypes.string // overrides the color() prop if set

  }), // values can also be passed directly
  propTypes.PropTypes.arrayOf(propTypes.PropTypes.number)])),
  label: propTypes.PropTypes.oneOfType([propTypes.PropTypes.func, propTypes.PropTypes._null]),
  scales: propTypes.PropTypes.arrayOf(propTypes.PropTypes.string),
  renderCheckpoints: propTypes.PropTypes.bool,
  reset: propTypes.PropTypes.bool,
  threshold: propTypes.PropTypes.bool,
  color: propTypes.PropTypes.func
};
LineChart.defaultProps = {
  springConfig: springs.springs.lazy,
  total: -1,
  height: 200,
  dotRadius: 7 / 2,
  animDelay: 500,
  rendercheckpoints: false,
  reset: false,
  borderColor: 'rgba(209, 209, 209, 0.5)',
  labelColor: 'white',
  lines: [],
  scales: [],
  threshold: false,
  label: index => index + 1,
  color: (index, _ref4) => {
    let {
      lines
    } = _ref4;
    return `hsl(${(index * (360 / lines.length) + 40) % 360}, 60%, 70%)`;
  }
};

var _StyledSvg = _styled__default["default"]("svg").withConfig({
  displayName: "LineChart___StyledSvg",
  componentId: "sc-1qmfila-0"
})(["display:block"]);

var _StyledText = _styled__default["default"]("text").withConfig({
  displayName: "LineChart___StyledText",
  componentId: "sc-1qmfila-1"
})(["alignment-baseline:middle;font-size:12px;font-weight:300;", ";"], css.unselectable);

var _StyledText2 = _styled__default["default"]("text").withConfig({
  displayName: "LineChart___StyledText2",
  componentId: "sc-1qmfila-2"
})(["alignment-baseline:middle;font-size:12px;font-weight:300;", ";", ""], css.unselectable, p => p.$_css);

exports["default"] = LineChart;
//# sourceMappingURL=LineChart.js.map
