'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('./extends-338edd51.js');
var _styled = require('styled-components');
var React = require('react');
var index = require('./index-00b34fc0.js');
var TextInput = require('./TextInput.js');
var ButtonIcon = require('./ButtonIcon.js');
var Theme = require('./Theme.js');
var IconCopy = require('./IconCopy.js');
var constants = require('./constants.js');
var environment = require('./environment.js');
var textStyles = require('./text-styles.js');
var miscellaneous = require('./miscellaneous.js');
require('./ButtonBase.js');
require('./FocusVisible.js');
require('./defineProperty-26e0e7dd.js');
require('./keycodes.js');
require('./css.js');
require('./theme-dark.js');
require('./theme-light.js');
require('./color.js');
require('./IconPropTypes-dbae899e.js');
require('./index-0f4db78b.js');
require('./font.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const HEIGHT = 5 * constants.GU;
const TextCopy = /*#__PURE__*/React__default["default"].memo( /*#__PURE__*/React__default["default"].forwardRef(function TextCopy(_ref, ref) {
  let {
    adornment,
    autofocus,
    message,
    monospace,
    onCopy,
    value,
    ...props
  } = _ref;
  const theme = Theme.useTheme();
  const inputRef = React.useRef(null); // Allows to focus the component from the outside

  React.useImperativeHandle(ref, () => ({
    focus: () => {
      inputRef.current.focus();
    }
  })); // Select the content on focus

  const handleFocus = React.useCallback(() => {
    inputRef.current && inputRef.current.select();
  }, []); // If onCopy is set (either to a function or null), Toast is not used.

  const onCopyOrToast = onCopy === undefined ? miscellaneous.noop : onCopy || miscellaneous.noop;
  const handleCopy = React.useCallback(() => {
    if (inputRef.current) {
      inputRef.current.focus();

      try {
        document.execCommand('copy');
        onCopyOrToast(message);
      } catch (err) {
        environment.warn(err);
      }
    }
  }, [message, onCopyOrToast]);
  return /*#__PURE__*/React__default["default"].createElement(_StyledDiv, _extends._extends({}, props, {
    $_css: adornment ? `${HEIGHT}px` : '0'
  }), /*#__PURE__*/React__default["default"].createElement(_StyledTextInput, {
    ref: inputRef,
    adornment: /*#__PURE__*/React__default["default"].createElement(_StyledButtonIcon, {
      onClick: handleCopy,
      label: "Copy",
      $_css2: HEIGHT - 2,
      $_css3: HEIGHT - 2,
      $_css4: theme.accentAlternative
    }, adornment || /*#__PURE__*/React__default["default"].createElement(IconCopy["default"], {
      size: "small"
    })),
    adornmentPosition: "end",
    adornmentSettings: {
      // Keep the button square
      width: HEIGHT - 2,
      padding: 0
    },
    autofocus: autofocus,
    onFocus: handleFocus,
    readOnly: true,
    value: value,
    wide: true,
    $_css5: adornment ? `
                  border-top-left-radius: 0;
                  border-bottom-left-radius: 0;
                  border-left: 0;
                ` : '',
    $_css6: textStyles.textStyle('body4'),
    $_css7: theme.surfaceContent
  }));
}));
TextCopy.propTypes = {
  adornment: index.PropTypes.node,
  autofocus: index.PropTypes.bool,
  message: index.PropTypes.string,
  monospace: index.PropTypes.bool,
  onCopy: index.PropTypes.func,
  value: index.PropTypes.string
};
TextCopy.defaultProps = {
  autofocus: false,
  message: 'Copied',
  monospace: true
};

var _StyledDiv = _styled__default["default"]("div").withConfig({
  displayName: "TextCopy___StyledDiv",
  componentId: "sc-1arm9f1-0"
})(["position:relative;display:inline-flex;max-width:100%;height:", "px;padding-left:", ";"], HEIGHT, p => p.$_css);

var _StyledButtonIcon = _styled__default["default"](ButtonIcon["default"]).withConfig({
  displayName: "TextCopy___StyledButtonIcon",
  componentId: "sc-1arm9f1-1"
})(["width:", "px;height:", "px;border-radius:0;color:", ";"], p => p.$_css2, p => p.$_css3, p => p.$_css4);

var _StyledTextInput = _styled__default["default"](TextInput["default"]).withConfig({
  displayName: "TextCopy___StyledTextInput",
  componentId: "sc-1arm9f1-2"
})(["text-overflow:ellipsis;height:", "px;max-width:100%;border:0px;", ";", ";&:read-only{color:", ";text-shadow:none;}"], HEIGHT, p => p.$_css5, p => p.$_css6, p => p.$_css7);

exports["default"] = TextCopy;
//# sourceMappingURL=TextCopy.js.map
