import _extends from '../../../node_modules/.pnpm/@babel_runtime@7.16.3/node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useContext, useMemo } from 'react';
import PropTypes from '../../../node_modules/.pnpm/prop-types@15.7.2/node_modules/prop-types/index.js';
import { useViewport as me } from '../../../node_modules/.pnpm/use-viewport@0.2.0_react@16.14.0/node_modules/use-viewport/dist/index.js';
import { BREAKPOINTS } from '../../style/breakpoints.js';
import { cssPx } from '../../utils/css.js';
import { GU } from '../../style/constants.js';

function getSizes(breakpoints) {
  return Object.entries(breakpoints).filter(_ref => {
    let [name] = _ref;
    return name !== 'min';
  }).sort((a, b) => a[1] - b[1]);
}

const breakpointsType = PropTypes.shape({
  min: PropTypes.number,
  small: PropTypes.number,
  medium: PropTypes.number,
  large: PropTypes.number
}); // Minimum margin around a layout

const MIN_MARGIN = 3 * GU;

function getLayoutSize(parentWidth, breakpoints) {
  const sizes = getSizes(breakpoints);
  let index = sizes.length;

  while (index--) {
    if (parentWidth >= sizes[index][1]) {
      return [sizes[index][0], sizes[index][1] - (index === 0 ? 0 : MIN_MARGIN * 2)];
    }
  }

  return sizes[0];
}

function useMergeBreakpoints(breakpoints) {
  const breakpointsAsString = JSON.stringify(breakpoints); // Only compute once by comparing values rather than object references in dependency array
  // eslint-disable-next-line react-hooks/exhaustive-deps

  return useMemo(() => ({ ...BREAKPOINTS,
    ...breakpoints
  }), [breakpointsAsString]);
}

const LayoutContext = /*#__PURE__*/React.createContext({});

function useLayout() {
  const {
    layoutWidth,
    layoutName
  } = useContext(LayoutContext);
  return {
    layoutName,
    layoutWidth
  };
}

function Layout(_ref2) {
  let {
    breakpoints,
    children,
    paddingBottom,
    parentWidth,
    ...props
  } = _ref2;
  const mergedBreakpoints = useMergeBreakpoints(breakpoints);
  return /*#__PURE__*/React.createElement(LayoutProvider, {
    parentWidth: parentWidth,
    breakpoints: breakpoints
  }, /*#__PURE__*/React.createElement(LayoutWidthLimiter, _extends({
    minWidth: mergedBreakpoints.min,
    paddingBottom: paddingBottom
  }, props), children));
}

Layout.propTypes = {
  breakpoints: breakpointsType,
  children: PropTypes.node,
  paddingBottom: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  parentWidth: PropTypes.number
};
Layout.defaultProps = {
  breakpoints: {},
  paddingBottom: 3 * GU
};

function LayoutProvider(_ref3) {
  let {
    breakpoints,
    children,
    parentWidth
  } = _ref3;
  const {
    width: viewportWidth
  } = me();
  const mergedBreakpoints = useMergeBreakpoints(breakpoints); // If the parent width is not passed, use the viewport width.

  const [layoutName, layoutWidth] = useMemo(() => getLayoutSize(parentWidth === undefined ? viewportWidth : parentWidth, mergedBreakpoints), [viewportWidth, parentWidth, mergedBreakpoints]);
  return /*#__PURE__*/React.createElement(LayoutContext.Provider, {
    value: {
      layoutWidth,
      layoutName
    }
  }, children);
}

LayoutProvider.propTypes = {
  breakpoints: breakpointsType,
  children: PropTypes.node,
  parentWidth: PropTypes.number
};
LayoutProvider.defaultProps = {
  breakpoints: {}
};
/* eslint-disable react/prop-types */

function LayoutWidthLimiter(_ref4) {
  let {
    children,
    minWidth,
    paddingBottom,
    ...props
  } = _ref4;
  const {
    layoutName,
    layoutWidth
  } = useLayout();
  return /*#__PURE__*/React.createElement(_StyledDiv, _extends({}, props, {
    $_css: layoutName === 'small' ? 'auto' : `${layoutWidth}px`,
    $_css2: minWidth,
    $_css3: cssPx(paddingBottom)
  }), children);
}

var _StyledDiv = _styled("div").withConfig({
  displayName: "Layout___StyledDiv",
  componentId: "sc-nxlhd9-0"
})(["width:", ";min-width:", "px;margin:0 auto;padding-bottom:", ";"], p => p.$_css, p => p.$_css2, p => p.$_css3);

export { LayoutProvider, Layout as default, useLayout };
//# sourceMappingURL=Layout.js.map
