import _extends from '../../../node_modules/.pnpm/@babel_runtime@7.16.3/node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useMemo, useCallback, useRef, useState, useEffect } from 'react';
import { Spring } from '../../../node_modules/.pnpm/react-spring@7.2.11_0106054ed56650b7cf08997e12b36ef5/node_modules/react-spring/web.js';
import PropTypes from '../../prop-types.js';
import { unselectable } from '../../utils/css.js';
import { GU } from '../../style/constants.js';
import { springs } from '../../style/springs.js';

const LABELS_HEIGHT = 30;
const WIDTH_DEFAULT = 300;

function useMeasuredWidth() {
  const ref = useRef();
  const [measuredWidth, setMeasuredWidth] = useState(WIDTH_DEFAULT);
  const onResize = useCallback(() => {
    if (ref.current) {
      setMeasuredWidth(ref.current.clientWidth);
    }
  }, []);
  const onRef = useCallback(element => {
    ref.current = element;
    onResize();
  }, [onResize]);
  useEffect(() => {
    window.addEventListener('resize', onResize);
    return () => window.removeEventListener('resize', onResize);
  }, [onResize]);
  return [measuredWidth, onRef];
}

const OFFSET = 50;

function LineChart(_ref) {
  let {
    animDelay,
    borderColor,
    color,
    dotRadius,
    height,
    label,
    labelColor,
    lines: linesProps,
    renderCheckpoints,
    reset,
    scales,
    springConfig,
    threshold,
    total,
    width: widthProps,
    ...props
  } = _ref;
  const [width, onSvgRef] = useMeasuredWidth();
  const lines = useMemo(() => {
    return linesProps.map(lineOrValues => Array.isArray(lineOrValues) ? {
      values: lineOrValues
    } : lineOrValues);
  }, [linesProps]); // the count of provided values

  const valuesCount = useMemo(() => {
    // All the values have the same length, so we can use the first one.
    return lines[0] ? lines[0].values.length : 0;
  }, [lines]); // the total amount of values

  const totalCount = useMemo(() => {
    // If no total is provided, the total is the number of provided values.
    return total > 0 && total > valuesCount ? total : valuesCount;
  }, [valuesCount, total]);
  const getX = useCallback(index => {
    return width / Math.max(1, totalCount - 1) * index;
  }, [width, totalCount]);
  const getY = useCallback((percentage, progress, height) => {
    const padding = dotRadius + 2;
    return height - padding - (height - padding * 2) * percentage * progress;
  }, [dotRadius]);
  const getLabelPosition = useCallback((index, length) => {
    if (index === 0) {
      return 'start';
    }

    if (index === length - 1) {
      return 'end';
    }

    return 'middle';
  }, []);
  const labels = label && totalCount > 0 ? [...Array(totalCount).keys()].map(label) : null;
  const chartHeight = height - (labels ? LABELS_HEIGHT : 0);
  return /*#__PURE__*/React.createElement(Spring, {
    from: {
      progress: 0
    },
    to: {
      progress: 1
    },
    config: springConfig,
    delay: animDelay,
    reset: reset
  }, _ref2 => {
    let {
      progress
    } = _ref2;
    return /*#__PURE__*/React.createElement(_StyledSvg, _extends({
      ref: onSvgRef,
      viewBox: `0 0 ${width + OFFSET} ${height + GU}`,
      width: widthProps || 'auto',
      height: "auto"
    }, props), /*#__PURE__*/React.createElement("g", {
      mask: "url(#chart-mask)",
      transform: `translate(0,${GU})`
    }, totalCount > 0 && /*#__PURE__*/React.createElement("path", {
      d: `
                  ${[...new Array(totalCount - 1)].reduce((path, _, index) => `${path} M ${getX(index)},${!index ? 0 : chartHeight} l 0,-8`, '')}
                `,
      stroke: borderColor,
      strokeWidth: "1"
    }), lines.map((line, lineIndex) => {
      return /*#__PURE__*/React.createElement("g", {
        key: `line-plot-${line.id || lineIndex}`
      }, /*#__PURE__*/React.createElement("path", {
        d: `
                    M
                    ${getX(0)},
                    ${getY(line.values[0], progress, chartHeight)}

                    ${line.values.slice(1).map((val, index) => {
          return `L
                           ${getX((index + 1) * progress)},
                           ${getY(val, progress, chartHeight, index)}
                          `;
        }).join('')}
                  `,
        fill: "transparent",
        stroke: line.color || color(lineIndex, {
          lines
        }),
        strokeWidth: "2"
      }), renderCheckpoints && line.values.slice(1, -1).map((val, index) => {
        return /*#__PURE__*/React.createElement("circle", {
          key: index,
          cx: getX(index + 1) * progress,
          cy: getY(val, progress, chartHeight),
          r: dotRadius,
          fill: color() || 'white',
          stroke: line.color || color(lineIndex, {
            lines
          }),
          strokeWidth: "1"
        });
      }));
    })), labels && /*#__PURE__*/React.createElement("g", {
      transform: `translate(0,${chartHeight})`
    }, labels.map((label, index) => /*#__PURE__*/React.createElement(_StyledText, {
      key: index,
      x: getX(index),
      y: LABELS_HEIGHT,
      textAnchor: getLabelPosition(index, labels.length),
      fill: labelColor
    }, label))), /*#__PURE__*/React.createElement("g", {
      transform: `translate(0,${GU})`
    }, scales && scales.map((_ref3, index) => {
      let {
        label,
        highlightColor
      } = _ref3;
      const scaleLength = scales.length - 1;
      return /*#__PURE__*/React.createElement(_StyledText2, {
        key: index,
        x: width + OFFSET / 8,
        y: chartHeight - chartHeight / scaleLength * index + GU / 2,
        textAnchor: getLabelPosition(0, labels.length),
        fill: highlightColor || labelColor,
        $_css: highlightColor && `
                        font-weight: 800;
                        font-size
                      `
      }, label);
    })), threshold && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("line", {
      x1: 0,
      y1: chartHeight / (scales.length - 1) + GU,
      x2: width,
      y2: chartHeight / (scales.length - 1) + GU,
      style: {
        stroke: '#952828',
        strokeWidth: 2
      }
    }), ' ', /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
      id: "thresholdFill",
      x1: "0",
      x2: "0",
      y1: "0",
      y2: "1"
    }, /*#__PURE__*/React.createElement("stop", {
      offset: "0%",
      stopColor: "red",
      stopOpacity: "0"
    }), /*#__PURE__*/React.createElement("stop", {
      offset: "100%",
      stopColor: "#952828",
      stopOpacity: "30%"
    }))), /*#__PURE__*/React.createElement("rect", {
      x: 0,
      y: 0,
      width: width,
      height: chartHeight / (scales.length - 1) + GU,
      fill: "url(#thresholdFill)"
    })));
  });
}

LineChart.propTypes = {
  springConfig: PropTypes._spring,
  total: PropTypes.number,
  width: PropTypes.number,
  height: PropTypes.number,
  dotRadius: PropTypes.number,
  animDelay: PropTypes.number,
  borderColor: PropTypes.string,
  labelColor: PropTypes.string,
  lines: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.shape({
    id: PropTypes.number,
    values: PropTypes.arrayOf(PropTypes.number).isRequired,
    // numbers between 0 and 1
    color: PropTypes.string // overrides the color() prop if set

  }), // values can also be passed directly
  PropTypes.arrayOf(PropTypes.number)])),
  label: PropTypes.oneOfType([PropTypes.func, PropTypes._null]),
  scales: PropTypes.arrayOf(PropTypes.string),
  renderCheckpoints: PropTypes.bool,
  reset: PropTypes.bool,
  threshold: PropTypes.bool,
  color: PropTypes.func
};
LineChart.defaultProps = {
  springConfig: springs.lazy,
  total: -1,
  height: 200,
  dotRadius: 7 / 2,
  animDelay: 500,
  rendercheckpoints: false,
  reset: false,
  borderColor: 'rgba(209, 209, 209, 0.5)',
  labelColor: 'white',
  lines: [],
  scales: [],
  threshold: false,
  label: index => index + 1,
  color: (index, _ref4) => {
    let {
      lines
    } = _ref4;
    return `hsl(${(index * (360 / lines.length) + 40) % 360}, 60%, 70%)`;
  }
};

var _StyledSvg = _styled("svg").withConfig({
  displayName: "LineChart___StyledSvg",
  componentId: "sc-1qmfila-0"
})(["display:block"]);

var _StyledText = _styled("text").withConfig({
  displayName: "LineChart___StyledText",
  componentId: "sc-1qmfila-1"
})(["alignment-baseline:middle;font-size:12px;font-weight:300;", ";"], unselectable);

var _StyledText2 = _styled("text").withConfig({
  displayName: "LineChart___StyledText2",
  componentId: "sc-1qmfila-2"
})(["alignment-baseline:middle;font-size:12px;font-weight:300;", ";", ""], unselectable, p => p.$_css);

export { LineChart as default };
//# sourceMappingURL=LineChart.js.map
