import _extends from '../../../node_modules/.pnpm/@babel_runtime@7.16.3/node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useRef, useImperativeHandle, useCallback } from 'react';
import PropTypes from '../../../node_modules/.pnpm/prop-types@15.7.2/node_modules/prop-types/index.js';
import WrapperTextInput from '../TextInput/TextInput.js';
import ButtonIcon from '../Button/ButtonIcon.js';
import { useTheme } from '../../theme/Theme.js';
import IconCopy from '../../icons/components/IconCopy.js';
import { GU } from '../../style/constants.js';
import { warn } from '../../utils/environment.js';
import { textStyle } from '../../style/text-styles.js';
import { noop } from '../../utils/miscellaneous.js';

const HEIGHT = 5 * GU;
const TextCopy = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(function TextCopy(_ref, ref) {
  let {
    adornment,
    autofocus,
    message,
    monospace,
    onCopy,
    value,
    ...props
  } = _ref;
  const theme = useTheme();
  const inputRef = useRef(null); // Allows to focus the component from the outside

  useImperativeHandle(ref, () => ({
    focus: () => {
      inputRef.current.focus();
    }
  })); // Select the content on focus

  const handleFocus = useCallback(() => {
    inputRef.current && inputRef.current.select();
  }, []); // If onCopy is set (either to a function or null), Toast is not used.

  const onCopyOrToast = onCopy === undefined ? noop : onCopy || noop;
  const handleCopy = useCallback(() => {
    if (inputRef.current) {
      inputRef.current.focus();

      try {
        document.execCommand('copy');
        onCopyOrToast(message);
      } catch (err) {
        warn(err);
      }
    }
  }, [message, onCopyOrToast]);
  return /*#__PURE__*/React.createElement(_StyledDiv, _extends({}, props, {
    $_css: adornment ? `${HEIGHT}px` : '0'
  }), /*#__PURE__*/React.createElement(_StyledTextInput, {
    ref: inputRef,
    adornment: /*#__PURE__*/React.createElement(_StyledButtonIcon, {
      onClick: handleCopy,
      label: "Copy",
      $_css2: HEIGHT - 2,
      $_css3: HEIGHT - 2,
      $_css4: theme.accentAlternative
    }, adornment || /*#__PURE__*/React.createElement(IconCopy, {
      size: "small"
    })),
    adornmentPosition: "end",
    adornmentSettings: {
      // Keep the button square
      width: HEIGHT - 2,
      padding: 0
    },
    autofocus: autofocus,
    onFocus: handleFocus,
    readOnly: true,
    value: value,
    wide: true,
    $_css5: adornment ? `
                  border-top-left-radius: 0;
                  border-bottom-left-radius: 0;
                  border-left: 0;
                ` : '',
    $_css6: textStyle('body4'),
    $_css7: theme.surfaceContent
  }));
}));
TextCopy.propTypes = {
  adornment: PropTypes.node,
  autofocus: PropTypes.bool,
  message: PropTypes.string,
  monospace: PropTypes.bool,
  onCopy: PropTypes.func,
  value: PropTypes.string
};
TextCopy.defaultProps = {
  autofocus: false,
  message: 'Copied',
  monospace: true
};

var _StyledDiv = _styled("div").withConfig({
  displayName: "TextCopy___StyledDiv",
  componentId: "sc-1arm9f1-0"
})(["position:relative;display:inline-flex;max-width:100%;height:", "px;padding-left:", ";"], HEIGHT, p => p.$_css);

var _StyledButtonIcon = _styled(ButtonIcon).withConfig({
  displayName: "TextCopy___StyledButtonIcon",
  componentId: "sc-1arm9f1-1"
})(["width:", "px;height:", "px;border-radius:0;color:", ";"], p => p.$_css2, p => p.$_css3, p => p.$_css4);

var _StyledTextInput = _styled(WrapperTextInput).withConfig({
  displayName: "TextCopy___StyledTextInput",
  componentId: "sc-1arm9f1-2"
})(["text-overflow:ellipsis;height:", "px;max-width:100%;border:0px;", ";", ";&:read-only{color:", ";text-shadow:none;}"], HEIGHT, p => p.$_css5, p => p.$_css6, p => p.$_css7);

export { TextCopy as default };
//# sourceMappingURL=TextCopy.js.map
