import _extends from '../../../node_modules/.pnpm/@babel_runtime@7.16.3/node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useCallback } from 'react';
import PropTypes from '../../../node_modules/.pnpm/prop-types@15.7.2/node_modules/prop-types/index.js';
import { useTheme } from '../../theme/Theme.js';
import { GU, RADIUS } from '../../style/constants.js';
import { textStyle } from '../../style/text-styles.js';

const TextInput = /*#__PURE__*/React.forwardRef((_ref, ref) => {
  let {
    autofocus,
    multiline,
    type,
    ...props
  } = _ref;
  const theme = useTheme();
  const handleRef = useCallback(element => {
    if (ref) {
      ref.current = element;
    }

    if (autofocus && element) {
      element.focus();
    }
  }, [autofocus, ref]);
  return /*#__PURE__*/React.createElement(_StyledInput, _extends({
    ref: handleRef,
    as: multiline ? 'textarea' : 'input',
    type: multiline ? undefined : type
  }, props, {
    $_css: 7 * GU,
    $_css2: 1.5 * GU,
    $_css3: theme.surfaceInteractive,
    $_css4: theme.surfaceInteractiveBorder,
    $_css5: theme.surfaceContent,
    $_css6: RADIUS / 2,
    $_css7: textStyle('body2'),
    $_css8: multiline ? `
              height: auto;
              padding: ${1 * GU}px ${1.5 * GU}px;
              resize: vertical;
            ` : '',
    $_css9: theme.accentAlternative,
    $_css10: theme.accentAlternative,
    $_css11: GU / 2,
    $_css12: theme.hint,
    $_css13: theme.border,
    $_css14: theme.placeholder
  }));
});

var _StyledTextInput = _styled(TextInput).withConfig({
  displayName: "TextInput___StyledTextInput",
  componentId: "sc-4uc1ir-0"
})(["", ":", "px;"], p => p.$_css16, p => p.$_css17);

TextInput.propTypes = {
  autofocus: PropTypes.bool,
  multiline: PropTypes.bool,
  required: PropTypes.bool,
  type: PropTypes.string
};
TextInput.defaultProps = {
  autofocus: false,
  multiline: false,
  required: false,
  type: 'text'
}; // Text input wrapped to allow adornments

const WrapperTextInput = /*#__PURE__*/React.forwardRef((_ref2, ref) => {
  let {
    adornment,
    adornmentPosition,
    adornmentSettings: {
      width: adornmentWidth = 56,
      padding: adornmentPadding = 24
    },
    ...props
  } = _ref2;
  const theme = useTheme();

  if (!adornment) {
    return /*#__PURE__*/React.createElement(TextInput, _extends({
      ref: ref
    }, props));
  }

  return /*#__PURE__*/React.createElement(_StyledDiv, {
    $_css15: props.wide ? '100%' : 'max-content'
  }, /*#__PURE__*/React.createElement(_StyledTextInput, _extends({
    ref: ref
  }, props, {
    $_css16: adornmentPosition === 'end' ? 'padding-right' : 'padding-left',
    $_css17: adornmentWidth
  })), /*#__PURE__*/React.createElement(_StyledDiv2, {
    $_css18: adornmentPosition === 'end' ? 'right' : 'left',
    $_css19: adornmentPadding,
    $_css20: theme.accentAlternative
  }, adornment));
});
WrapperTextInput.propTypes = { ...TextInput.propTypes,
  adornment: PropTypes.node,
  adornmentPosition: PropTypes.oneOf(['start', 'end']),
  adornmentSettings: PropTypes.shape({
    width: PropTypes.number,
    padding: PropTypes.number
  })
};
WrapperTextInput.defaultProps = { ...TextInput.defaultProps,
  adornment: null,
  adornmentPosition: 'start',
  adornmentSettings: {}
}; // Multiline input (textarea element)

function TextInputMultiline(props) {
  return /*#__PURE__*/React.createElement(TextInput, _extends({
    multiline: true
  }, props));
}

TextInputMultiline.propTypes = {
  required: PropTypes.bool
};
TextInputMultiline.defaultProps = {
  required: false
};
WrapperTextInput.Multiline = TextInputMultiline;

var _StyledInput = _styled("input").withConfig({
  displayName: "TextInput___StyledInput",
  componentId: "sc-4uc1ir-1"
})(["width:", ";height:", "px;padding:0 ", "px;background:", ";border:2px solid ", ";color:", ";border-radius:", "px;appearance:none;", ";transition:all 50ms ease-in-out;", " &:hover{border-color:", ";}&:focus{outline:none;border-color:", ";border-width:", "px;}&:read-only{color:", ";border-color:", ";}&::placeholder{color:", ";opacity:1;}&:invalid{box-shadow:none;}"], _ref3 => {
  let {
    wide
  } = _ref3;
  return wide ? '100%' : 'auto';
}, p => p.$_css, p => p.$_css2, p => p.$_css3, p => p.$_css4, p => p.$_css5, p => p.$_css6, p => p.$_css7, p => p.$_css8, p => p.$_css9, p => p.$_css10, p => p.$_css11, p => p.$_css12, p => p.$_css13, p => p.$_css14);

var _StyledDiv = _styled("div").withConfig({
  displayName: "TextInput___StyledDiv",
  componentId: "sc-4uc1ir-2"
})(["display:inline-flex;position:relative;width:", ";"], p => p.$_css15);

var _StyledDiv2 = _styled("div").withConfig({
  displayName: "TextInput___StyledDiv2",
  componentId: "sc-4uc1ir-3"
})(["position:absolute;top:0;bottom:0;height:100%;", ":", "px;display:flex;align-items:center;justify-content:center;color:", ";"], p => p.$_css18, p => p.$_css19, p => p.$_css20);

export { WrapperTextInput as default };
//# sourceMappingURL=TextInput.js.map
